<?php

namespace Drupal\cloudflare_stream\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Defines a form that configures the settings for Cloudflare Stream module.
 */
class CloudflareStreamSettings extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'cloudflare_stream.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'cloudflare_stream_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    // Getting already saved config from the database.
    $email = $this->config('cloudflare_stream.settings')->get('email');
    $api_key = $this->config('cloudflare_stream.settings')->get('api_key');
    $account_id = $this->config('cloudflare_stream.settings')->get('account_id');
    $zone_id = $this->config('cloudflare_stream.settings')->get('zone_id');

    // Adding form fields to the form.
    $form['email'] = [
      '#type' => 'email',
      '#title' => $this->t('Email Address'),
      '#description' => $this->t('Your Cloudflare login email address'),
      '#default_value' => $email,
      '#required' => TRUE,
    ];
    $form['api_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('API Key'),
      '#description' => $this->t('Your Cloudflare API key'),
      '#default_value' => $api_key,
      '#required' => TRUE,
    ];
    $form['account_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Account ID'),
      '#default_value' => $account_id,
      '#required' => TRUE,
    ];
    $form['zone_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Zone ID'),
      '#default_value' => $zone_id,
      '#required' => TRUE,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Trimming user entry for any whitespace.
    $email = preg_replace('/\s/', '', $form_state->getValue('email'));
    $api_key = preg_replace('/\s/', '', $form_state->getValue('api_key'));
    $account_id = preg_replace('/\s/', '', $form_state->getValue('account_id'));
    $zone_id = preg_replace('/\s/', '', $form_state->getValue('zone_id'));

    // Saving config in the database.
    $this->config('cloudflare_stream.settings')
      ->set('email', $email)
      ->set('api_key', $api_key)
      ->set('account_id', $account_id)
      ->set('zone_id', $zone_id)
      ->save();
    $this->messenger()->addMessage($this->t('Cloudflare configurations saved successfully.'));
  }

}
